-- Tests for HazLootList functions, especially the loot comparator

require("HazLootList")
require("WoWMock")

function TestSetup()
  print("*** Setting up HazLootList tests")
  print("*** Setup succeeded")
end

function TestTeardown()
  print("*** Tearing down HazLootList tests")
  print("*** Teardown succeeded")
end

function TestAddItem()
  print("*** Testing AddItem()")
  assert(-1 == HLL:AddItem(), "Expected to fail adding a nil item")
  assert(-1 == HLL:AddItem(""), "Expected to fail adding an empty item")
  assert(1  == HLL:AddItem("Item1"), "Expected to be able to add role-less 'Item1'")
  assert(2  == HLL:AddItem("Item2|"), "Expected to be able to add role-less 'Item2', with separator")
  assert(-1 == HLL:AddItem("Item3|BadRole"), "Expected to fail adding Item3 with bad role")
  assert(-1 == HLL:AddItem("Item3|BadRole:Druid"), "Expected to fail adding Item3 with bad role and restriction")
  assert(-1 == HLL:AddItem("Item3|Healer:Magician"), "Expected to fail adding Item3 with good role and bad restriction")
  assert(3  == HLL:AddItem("Item3|Caster DPS"), "Expected to be able to add 'Item3|Caster DPS'")
  assert(4  == HLL:AddItem("Item4|Healer"), "Expected to be able to add 'Item4|Healer'")
  assert(5  == HLL:AddItem("Item5|Physical DPS"), "Expected to be able to add 'Item5|Physical DPS'")
  assert(6  == HLL:AddItem("Item6|Tank"), "Expected to be able to add 'Item6|Tank'")
  assert(7  == HLL:AddItem("Item7|Random roll"), "Expected to be able to add 'Item7|Random roll'")
  assert(8  == HLL:AddItem("Item8|Tier piece"), "Expected to be able to add 'Item8|Tier piece'")
  assert(9  == HLL:AddItem("Item9|Caster DPS,Healer"), "Expected to be able to add 'Item9|Caster DPS,Healer'")
  assert(10  == HLL:AddItem("Item10|Physical DPS:Druid,Tank:Druid"), "Expected to be able to add 'Item10|Physical DPS:Druid,Tank:Druid")
  assert(-1  == HLL:AddItem("Item10|Physical DPS:Druid,Tank:Fat Bastard"), "Expected to fail adding 'Item10|Physical DPS:Druid,Tank:Fat Bastard")
  assert(-1  == HLL:AddItem("Item10|Physical DPS:Fat Bastard,Tank:Druid"), "Expected to fail adding 'Item10|Physical DPS:Fat Bastard,Tank:Druid")
  assert(11  == HLL:AddItem("Item11|Tier piece:Hunter,Tier piece:Shaman,Tier piece:Warrior"), "Expected to be able to add 'Item11|Tier piece:Hunter,Tier piece:Shaman,Tier piece:Warrior'")
  assert(11  == HLL:AddItem("Item11|Random roll"), "Expected to be able to overwrite 'Item11|Random roll'")
  assert(11  == HLL:AddItem("Item11|Tier piece:Hunter,Tier piece:Shaman,Tier piece:Warrior"), "Expected to be able to restore 'Item11|Tier piece:Hunter,Tier piece:Shaman,Tier piece:Warrior'")
  print("*** AddItem() seems to work as expected")
end

TestSetup()
TestAddItem()
TestTeardown()

--[[ TEMPLATE

function TestXXX()
  print("*** Testing XXX()")
  print("*** XXX() seems to work as expected")
end

-- ]]--

